@@ -86,7 +86,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55300
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55300
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -151,6 +151,18 @@
 #else
 #  define KWIDGETSADDONS_DEPRECATED_VERSION_5_78(text)
 #endif
+
+#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_85(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_85(text)
+#endif
+
+#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KWIDGETSADDONS_DEPRECATED_VERSION_5(minor, text)      KWIDGETSADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -216,7 +228,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55300
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -226,7 +238,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55300
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -281,6 +293,18 @@
 #else
 #  define KWIDGETSADDONS_DEPRECATED_VERSION_5_78(text)
 #endif
+
+#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_85(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_85(text)
+#endif
+
+#if KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text) KWIDGETSADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWIDGETSADDONS_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KWIDGETSADDONS_DEPRECATED_VERSION_5(minor, text)      KWIDGETSADDONS_DEPRECATED_VERSION_5_##minor(text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION(major, minor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWIDGETSADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWIDGETSADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
